Coverage for src/remedapy/__init__.py: 100%

1 from .add import add

2 from .all_pass import all_pass

3 from .any_pass import any_pass

4 from .capitalise import capitalise

5 from .default_to import default_to

6 from .difference import difference

7 from .difference_with import difference_with

8 from .ends_with import ends_with

9 from .filter import filter

10 from .find import find

11 from .find_index import find_index

12 from .map import map

13 from .multiply import multiply

14 from .only import only

15 from .pipe import pipe

16 from .piped import piped

17 from .prop import prop

18 from .random_string import random_string

19 from .range import range

20 from .reduce import reduce

21 from .splice import splice

22 from .starts_with import starts_with

23 from .subtract import subtract

24 from .take import take

25 from .tap import tap

26 from .uncapitalise import uncapitalise

27 from .unique import unique

28

29 __all__ = [

30 'add',

31 'all_pass',

32 'any_pass',

33 'capitalise',

34 'default_to',

35 'difference',

36 'difference_with',

37 'ends_with',

38 'filter',

39 'find',

40 'find_index',

41 'map',

42 'multiply',

43 'only',

44 'pipe',

45 'piped',

46 'prop',

47 'random_string',

48 'range',

49 'reduce',

50 'splice',

51 'starts_with',

52 'subtract',

53 'take',

54 'tap',

55 'uncapitalise',

56 'unique',

57]